==> govuk_frontend_django-0.1.0.tar.gz: govuk_frontend_django-0.1.0/govuk_frontend_django/templatetags/govuk_frontend_django/pagination.py <==
from typing import List, Optional

from django import template
from django.core.paginator import Page

from govuk_frontend_django.components.pagination import (
    GovUKPagination,
    PaginationItems,
    PaginationNext,
    PaginationPrevious,
)

register = template.Library()


@register.simple_tag
def gds_pagination(page_obj: Page):
    """GDS pagination template tag.

    Args:
        page_obj (Page):
            The Django Paginator Page object.

    Usage:
        This template tag is designed to be used with the Django pagination,
        below is an example of it being used with a ListView.

        *views.py:*
        ```python
        from django.views.generic import ListView
        from django.contrib.auth import get_user_model

        User = get_user_model()


        class UserListingView(ListView):
            template_name = "template.html"
            model = User
            paginate_by = 25
        ```

        *template.html:*
        ```django
        {% load govuk_frontend_django %}
        {% gds_pagination page_obj %}
        ```
    """

    previous: Optional[PaginationPrevious] = None
    next: Optional[PaginationNext] = None
    pagination_items: List[PaginationItems] = []

    if page_obj.has_previous():
        previous = PaginationPrevious(
            href=f"?page={page_obj.previous_page_number()}",
            labelText="Previous",
        ).__dict__

    if page_obj.has_next():
        next = PaginationNext(
            href=f"?page={page_obj.next_page_number()}",
            labelText="Next",
        ).__dict__

    for page_number in page_obj.paginator.get_elided_page_range(
        page_obj.number, on_each_side=2, on_ends=1
    ):
        if page_number == "...":
            pagination_items.append({"ellipsis": True})
        else:
            pagination_items.append(
                {
                    "number": page_number,
                    "current": page_number == page_obj.number,
                    "href": f"?page={page_number}",
                }
            )

    return GovUKPagination(previous=previous, next=next, items=pagination_items)

==> govuk_frontend_django-0.3.4.tar.gz: govuk_frontend_django-0.3.4/govuk_frontend_django/templatetags/govuk_frontend_django/pagination.py <==
from typing import List, Optional

from django import template
from django.core.paginator import Page

from govuk_frontend_django.components.pagination import (
    GovUKPagination,
    PaginationItems,
    PaginationNext,
    PaginationPrevious,
)

register = template.Library()


@register.simple_tag
def gds_pagination(page_obj: Page):
    """GDS pagination template tag.

    Args:
        page_obj (Page):
            The Django Paginator Page object.

    Usage:
        This template tag is designed to be used with the Django pagination,
        below is an example of it being used with a ListView.

        *views.py:*
        ```python
        from django.views.generic import ListView
        from django.contrib.auth import get_user_model

        User = get_user_model()


        class UserListingView(ListView):
            template_name = "template.html"
            model = User
            paginate_by = 25
        ```

        *template.html:*
        ```django
        {% load govuk_frontend_django %}
        {% gds_pagination page_obj %}
        ```
    """

    previous: Optional[PaginationPrevious] = None
    next: Optional[PaginationNext] = None
    pagination_items: List[PaginationItems] = []

    if page_obj.has_previous():
        previous = PaginationPrevious(
            href=f"?page={page_obj.previous_page_number()}",
            labelText="Previous",
        ).__dict__  # type: ignore

    if page_obj.has_next():
        next = PaginationNext(
            href=f"?page={page_obj.next_page_number()}",
            labelText="Next",
        ).__dict__  # type: ignore

    for page_number in page_obj.paginator.get_elided_page_range(  # type: ignore
        page_obj.number, on_each_side=2, on_ends=1
    ):
        if page_number == "...":
            pagination_items.append({"ellipsis": True})  # type: ignore
        else:
            pagination_items.append(
                {
                    "number": page_number,
                    "current": page_number == page_obj.number,
                    "href": f"?page={page_number}",
                }  # type: ignore
            )

    return GovUKPagination(previous=previous, next=next, items=pagination_items)
